# History

## 1.1.0 (2020-04-28)

  - Add spanish translations

## 1.0.7 (2020-04-27)

  - Add possibility to i18n strings

## 1.0.6 (2020-04-15)

  - Remove debugging print statements
  - use default_app_config for easier integration
  - Support dynamically-added inline forms

## 1.0.5 (2019-12-30)

  - Add python 3.8 and Django 3.0 to tests

## 1.0.4 (2019-09-02)

  - Can add item after removing everything from the list

## 1.0.3 (2019-09-02)

  - Can add item after removing everything from the list
  - Do not call static at startup time

## 1.0.2 (2019-04-03)

  - If field is required empty list raises ValidationError on clean.

## 1.0.1 (2019-02-23)

  - Empty list is no longer recognized as changed.


## 1.0.0 (2019-02-21)

  - First release on PyPI.
